<?php
/*
Plugin Name: Rate my Post
Plugin URI: https://wordpress.org/plugins/rate-my-post/
Description: Allows visitors to rate your posts/pages and send you private feedback about each post or page.
Version: 1.1.2
Author: Blaz K.
License: GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: rate-my-post
*/

//======================================================================
// TABLE OF CONTENTS
//	1. SCRIPTS AND STYLES
//		1.1. FRONTEND CSS
//		1.2. FRONTEND JAVASCRIPT
//		1.3. BACKEND CSS
//		1.4. BACKEND JAVASCRIPT
//	2. MULTI-LANGUAGE SUPPORT
//	3. SHORTCODES SUPPORT
//	4. ADD RMP TO EVERY POST OR PAGE
//	5. FRONTEND AJAX  - RATING, FEEDBACK AND ASYNC LOAD OF RESULTS
//		5.1. PROCESS ASYNC LOAD
//		5.2. PROCESS RATING
//		5.3. PROCESS FEEDBACK
//	6. BACKEND AJAX  - UPDATE RESULTS IN BACKEND
//	7. META BOX - ALLOWS RESULTS UPDATE IN BACKEND
//	8. PLUGIN SETTINGS AND STATS + MENU ITEM
//    8.1. BASIC SETTINGS
//    8.2. CUSTOMIZE
//    8.3. ADMIN MENU SECTION
//	9. HELPER FUNCTIONS
//    9.1. DEFAULT BASIC OPTIONS
//    9.2. DEFAULT CUSTOMIZATION OPTIONS
//    9.3. FRONTEND HTML
//    9.4. META BOX HTML
//    9.5. OPTIONS HTML
//    9.6 OPTIONS - NAVIGATION
//    9.7 ABOUT BOX
//    9.8 OPTIONS - SETTINGS TAB
//    9.9 OPTIONS - CUSTOMIZE TAB
//    9.10 OPTIONS - STATS TAB
//    9.11 CUSTOM STRINGS - FRONT AND BACKEND
//    9.12 CUSTOM STYLE - BACKEND
//    9.13 CUSTOM STYLE - FONT SIZE FRONTEND
//    9.14 CUSTOM STYLE - MARGIN FRONTEND
//    9.15 CUSTOM STYLE - SOCIAL ICON FRONTEND
//    9.16 VERSION CHANGE OPTIONS UPDATE
//    9.17 VERSION CHANGE CUSTOMIZATION OPTIONS UPDATE

//======================================================================

//======================================================================
// 1. SCRIPTS AND STYLES
//======================================================================

//1.1. FRONTEND CSS
function rmp_enqueue_css() {
    wp_register_style( 'rmp_rate_css', plugins_url('css/rmp-rate.css', __FILE__) );
    wp_register_style( 'rmp_font_awesome', plugins_url( 'css/font-awesome.min.css', __FILE__ ) );
    //include rmp in every post is on
    $rmp_options = get_option( 'rmp_options' );
    if( $rmp_options['posts'] === 2 && is_singular('post') ) {
      wp_enqueue_style( 'rmp_rate_css' );
      wp_enqueue_style( 'rmp_font_awesome' );
    }
    //include rmp in every page is on
    if( $rmp_options['pages'] === 2 && is_page() ) {
      wp_enqueue_style( 'rmp_rate_css' );
      wp_enqueue_style( 'rmp_font_awesome' );
    }
}

add_action( 'wp_enqueue_scripts', 'rmp_enqueue_css' );

//1.2. FRONTEND JAVASCRIPT
function rmp_enqueue_js() {
    wp_register_script( 'rmp_rate_js', plugins_url( 'js/rmp-rate.js', __FILE__ ), array ('jquery'),  '1.1', true );
    wp_register_script( 'rmp_cookie_js', plugins_url( 'js/js.cookie.js', __FILE__ ), array ('jquery'),  '1.1', true );
    //get plugin options
    $rmp_options = get_option( 'rmp_options' );
    //localize script
    wp_localize_script(
      'rmp_rate_js',
      'article_rating',
       array(
         'admin_ajax'      => admin_url( 'admin-ajax.php' ),
         'postID'          => get_the_id(),
         'noVotes'         => ( esc_html__( rmp_custom_string('noRating') ) ),
         'cookie'          => ( esc_html__( rmp_custom_string('cookieNotice') ) ),
         'afterVote'       => ( esc_html__( rmp_custom_string('afterVote') ) ),
         'social'          => $rmp_options['social'],
         'feedback'        => $rmp_options['feedback'],
         'cookieDisable'   => $rmp_options['cookieDisable'],
         'emptyFeedback'   => ( esc_html__( rmp_custom_string('feedbackAlert') ) ),
            )
      );
      //include rmp in every post is on
      if( $rmp_options['posts'] === 2 && is_singular('post') ) {
        wp_enqueue_script( 'rmp_rate_js' );
        wp_enqueue_script( 'rmp_cookie_js' );
      }
      //include rmp in every page is on
      if( $rmp_options['pages'] === 2 && is_page() ) {
        wp_enqueue_script( 'rmp_rate_js' );
        wp_enqueue_script( 'rmp_cookie_js' );
      }
}

add_action( 'wp_enqueue_scripts', 'rmp_enqueue_js' );

//1.3. BACKEND CSS
function rmp_enqueue_admin_css() {
    wp_enqueue_style( 'rmp_rate_admin_css', plugins_url('css/rmp-rate-admin.css', __FILE__) );
}
add_action( 'admin_enqueue_scripts', 'rmp_enqueue_admin_css' );

//1.4. BACKEND JAVASCRIPT
//admin js - backend update
function rmp_enqueue_admin_rate_js() {
    wp_register_script( 'rmp_rate_admin_js', plugins_url( 'js/rmp-rate-admin.js', __FILE__ ), array ('jquery'),  '1.1', true );
    wp_enqueue_script( 'rmp_rate_admin_js' );
    //ajax ready
    wp_localize_script(
      'rmp_rate_admin_js',
      'update_rating',
       array(
         'admin_ajax' => admin_url( 'admin-ajax.php' ),
         'postID'     => get_the_id(),
            )
      );
}

add_action( 'admin_enqueue_scripts', 'rmp_enqueue_admin_rate_js' );

//admin js - plugin options

function rmp_enqueue_options_js() {
    wp_register_script( 'rmp_options_js', plugins_url( 'js/rmp-options-admin.js', __FILE__ ), array ('jquery'),  '1.1', true );
    wp_enqueue_script( 'rmp_options_js' );
    //ajax ready
    wp_localize_script(
      'rmp_options_js',
      'rmp_options',
       array(
         'admin_ajax' => admin_url( 'admin-ajax.php' ),
         'save'       => ( esc_html__( 'Saving', 'rate-my-post' ) ),
         'resetConfirm'       => ( esc_html__( 'Are your sure you want to reset the settings?', 'rate-my-post' ) ),
        )
      );
}

add_action( 'admin_enqueue_scripts', 'rmp_enqueue_options_js' );

//admin js - customize

function rmp_enqueue_customize_js() {
    wp_register_script( 'rmp_customize_js', plugins_url( 'js/rmp-customize-admin.js', __FILE__ ), array ('jquery'),  '1.1', true );
    wp_enqueue_script( 'rmp_customize_js' );
    //ajax ready
    wp_localize_script(
      'rmp_customize_js',
      'rmp_customize',
       array(
         'admin_ajax' => admin_url( 'admin-ajax.php' ),
         'save'       => ( esc_html__( 'Saving', 'rate-my-post' ) ),
         'resetConfirm'       => ( esc_html__( 'Are your sure you want to reset the customization options?', 'rate-my-post' ) ),
        )
      );
}

add_action( 'admin_enqueue_scripts', 'rmp_enqueue_customize_js' );

//======================================================================
// 2. MULTI-LANGUAGE SUPPORT
//======================================================================

function rmp_load_textdomain() {
	load_plugin_textdomain( 'rate-my-post', false, dirname( plugin_basename(__FILE__) ) . '/lang/' );
}

add_action( 'plugins_loaded', 'rmp_load_textdomain' );

//======================================================================
// 3. SHORTCODES SUPPORT
//======================================================================

function rmp_shortcode(){
  //scripts and styles
  wp_enqueue_style( 'rmp_rate_css' );
  wp_enqueue_style( 'rmp_font_awesome' );
  wp_enqueue_script( 'rmp_rate_js' );
  wp_enqueue_script( 'rmp_cookie_js' );
  //print html
  return rmp_print_frontend_html();
}

add_shortcode( 'ratemypost', 'rmp_shortcode' );

//======================================================================
// 4. ADD RMP TO EVERY POST OR PAGE
//======================================================================

function rmp_every_post_page( $content ) {
  $rmp_options = get_option( 'rmp_options' );
  //some posts/pages have to be exluded
  if ( !empty( $rmp_options['exclude'] ) ) {
    //add to every post but not to excluded ones
    if ( $rmp_options['posts'] === 2 && is_singular('post') && !is_single( $rmp_options['exclude'] ) ) {
      $rmp_content = rmp_print_frontend_html();
      $content .= $rmp_content;
      return $content;

    } elseif ( $rmp_options['pages'] === 2 && is_page() && !is_page( $rmp_options['exclude'] ) ) {
      //add to every page but not to excluded ones
      $rmp_content = rmp_print_frontend_html();
      $content .= $rmp_content;
      return $content;
    } else {
      //just return the content
      return $content;
    }
  //nothing to exclude - the excluded array is empty
  } else {
    //add to every post
    if ( $rmp_options['posts'] === 2 && is_singular('post') ) {
      $rmp_content = rmp_print_frontend_html();
      $content .= $rmp_content;
      return $content;

    } elseif ( $rmp_options['pages'] === 2 && is_page() ) {
      //add to every page
      $rmp_content = rmp_print_frontend_html();
      $content .= $rmp_content;
      return $content;
    } else {
      //just return the content
      return $content;
    }
  }
}
add_filter( 'the_content', 'rmp_every_post_page' );

//======================================================================
// 5. FRONTEND AJAX  - RATING, FEEDBACK AND ASYNC LOAD OF RESULTS
//======================================================================

function rmp_process_rating() {
  if ( wp_doing_ajax() ) {
    //get id of the actual post
    $postID = intval( $_POST['postID'] );
    //get plugin options
    $rmp_options = get_option( 'rmp_options' );

    //5.1. PROCESS ASYNC LOAD
    if ( ! $_POST['star_rating'] && ! $_POST['feedback'] ) {
      $votes = intval( get_post_meta( $postID, 'rmp_vote_count', true ) );
      $ratingSum = intval( get_post_meta( $postID, 'rmp_rating_val_sum', true ) );
      if ($votes && $ratingSum) {
        $avgRating = round( ($ratingSum / $votes), 1 );
        echo $votes . '||' . $avgRating;
      } else {
        echo '0||0';
      }
    }

    //5.2. PROCESS RATING
    if ( ! $_POST['feedback'] && ! $_POST['loadResults'] ) {
      $rating = intval( $_POST['star_rating'] );
      if ( ! $rating ) {
        //do nothing
      } else {
        //insert vote count to the database as post meta
        if ( ! add_post_meta( $postID, 'rmp_vote_count', 1, true ) ) {
          $currentVoteCount = intval( get_post_meta( $postID, 'rmp_vote_count', true ) );
          $newVoteCount = intval( $currentVoteCount + 1 );
          update_post_meta( $postID, 'rmp_vote_count', $newVoteCount );
        }
        //insert rating sum to the database as post meta
        if ( ! add_post_meta( $postID, 'rmp_rating_val_sum', $rating, true ) ) {
          $currentRating = intval( get_post_meta( $postID, 'rmp_rating_val_sum', true ) );
          $newRating = intval( $currentRating + $rating );
          update_post_meta( $postID, 'rmp_rating_val_sum', $newRating );
        }
        //send email on votes
        if( $rmp_options['rate_email'] == 2 ) {
        $to = get_bloginfo( 'admin_email' );
        $subject = '[RMP]Somebody rated ' . get_the_title( $postID );
        $message = get_the_title( $postID ) . ' was rated ' . $rating . ' and now has an average rating of ' . round( (get_post_meta( $postID, 'rmp_rating_val_sum', true ) / get_post_meta( $postID, 'rmp_vote_count', true ) ), 1 ) . '.';
        wp_mail( $to, $subject, $message );
        }
      }
    }

    //5.3. PROCESS FEEDBACK
    if ( ! $_POST['star_rating'] && ! $_POST['loadResults'] ) {
      $feedback = sanitize_text_field( $_POST['feedback'] );
      //check that feedback is not empty
      if ( str_replace(' ', '', $feedback) ) {
      //insert it to database
        if ( ! add_post_meta( $postID, 'rmp_feedback_val', '<b>Feedback:</b> ' . $feedback . '<br />', true ) ) {
          $currentFeedback = get_post_meta( $postID, 'rmp_feedback_val', true );
          $newFeedback = $currentFeedback . ' ' . '<b>Feedback:</b> ' . $feedback;
          update_post_meta( $postID, 'rmp_feedback_val', $newFeedback . '<br />' );
        }
        //send email on feedback
        if( $rmp_options['feedback_email'] == 2 ) {
        $to = get_bloginfo( 'admin_email' );
        $subject = '[RMP]Somebody left feedback on ' . get_the_title( $postID );
        $message = 'Feedback on ' . get_the_title( $postID ) . ': ' . $feedback;
        wp_mail( $to, $subject, $message);
        }
      }
    }
  };
  die();
}

add_action( 'wp_ajax_process_rating', 'rmp_process_rating' );
add_action( 'wp_ajax_nopriv_process_rating', 'rmp_process_rating' );

//======================================================================
// 6. BACKEND AJAX  - UPDATE RESULTS IN BACKEND
//======================================================================

function rmp_backend_rating_update() {
  if ( wp_doing_ajax() && current_user_can('edit_posts') ) {
    $newVotes = intval( $_POST['votes'] );
    $newSum = intval( $_POST['sum'] );
    $newAvg = intval( ceil( $_POST['avg'] ) );
    $postID = intval( $_POST['postID'] );
    //update votes
    if( $newAvg > 0 && $newAvg < 6 || $newAvg === 0 && $newVotes === 0 && $newSum === 0) {
      if ( ! add_post_meta( $postID, 'rmp_vote_count', $newVotes, true ) ) {
        update_post_meta( $postID, 'rmp_vote_count', $newVotes );
      }
      if ( ! add_post_meta( $postID, 'rmp_rating_val_sum', $newSum, true ) ) {
        update_post_meta( $postID, 'rmp_rating_val_sum', $newSum );
      }
      echo esc_html__( 'Number of votes and sum of ratings successfully updated!');
    } else {
      echo esc_html__( 'Update failed - please try again!');
    }
  };
  die();
}

add_action( 'wp_ajax_update_rating', 'rmp_backend_rating_update' );

//======================================================================
// 7. META BOX - ALLOWS RESULTS UPDATE IN BACKEND
//======================================================================

//register meta box
function rmp_meta_boxes() {
    add_meta_box( 'rmp-rate-id', 'Rate my Post', 'rmp_display_metabox', array( 'post', 'page' ) );
}
add_action( 'add_meta_boxes', 'rmp_meta_boxes' );

//display meta box
function rmp_display_metabox ( $post ) {
    $postID = $post->ID;
    //number of votes
    $votes = intval( get_post_meta( $postID, 'rmp_vote_count', true ) );
    //sum of ratings
    $ratingSum = intval( get_post_meta( $postID, 'rmp_rating_val_sum', true ) );
    //feedback
    $feedback = get_post_meta( $postID, 'rmp_feedback_val', true );
    if($feedback === '') {
      $feedback = esc_html__( 'No feedback so far!', 'rate-my-post' );
    }
    //average rating
    if( intval($votes) ) {
      $avgRating = round( $ratingSum / $votes, 1 );
    } else {
      $avgRating = 'n/a';
    }

    echo rmp_metabox_html( $votes, $ratingSum, $avgRating, $feedback );
}

//======================================================================
// 8. PLUGIN SETTINGS AND STATS + MENU ITEM
//======================================================================

//8.1. BASIC SETTINGS

//add options
$rmp_options = rmp_default_options();
add_option( 'rmp_options', $rmp_options );

//modify uptions array on update
rmp_options_modify();

//update or reset options via ajax
function rmp_options_update() {
  //only admin can update options
  if ( wp_doing_ajax() && current_user_can( 'manage_options' ) ) {
    if( intval( $_POST['save'] ) === 1 ) { //we are updating not reseting
      //form an array of options
        $rmp_options_update = array();
        $rmp_options_update['posts'] = intval( $_POST['posts'] );
        $rmp_options_update['pages'] = intval( $_POST['pages'] );
        $rmp_options_update['rate_email'] = intval( $_POST['rateEmail'] );
        $rmp_options_update['feedback_email'] = intval( $_POST['feedbackEmail'] );
        $rmp_options_update['feedback'] = intval( $_POST['feedback'] );
        $rmp_options_update['social'] = intval( $_POST['social'] );
        $rmp_options_update['fb'] = esc_url( str_replace(' ', '', $_POST['facebook'] ) );
        $rmp_options_update['pinterest'] = esc_url( str_replace(' ', '', $_POST['pinterest'] ) );
        $rmp_options_update['flickr'] = esc_url( str_replace(' ', '', $_POST['flickr'] ) );
        $rmp_options_update['youtube'] = esc_url( str_replace(' ', '', $_POST['youtube'] ) );
        $rmp_options_update['instagram'] = esc_url( str_replace(' ', '', $_POST['instagram'] ) );
        $rmp_options_update['twitter'] = esc_url( str_replace(' ', '', $_POST['twitter'] ) );
        $rmp_options_update['linkedin'] = esc_url( str_replace(' ', '', $_POST['linkedin'] ) );

        //exclude from needs further attention - it is an array
        $rmp_exclude = array();
        $rmp_exclude_input_array = explode( ',',( $_POST['exclude'] ) );
        foreach ( $rmp_exclude_input_array as $rmp_exclude_id) {
          $rmp_exclude_id_int = intval($rmp_exclude_id);
          if ($rmp_exclude_id_int !== 0) {
            $rmp_exclude[] = $rmp_exclude_id_int;
          }
        }

        //add to main options array
        $rmp_options_update['exclude'] = $rmp_exclude;
        $rmp_options_update['cookieDisable'] = intval( $_POST['cookieDis'] );

        //update options
        update_option( 'rmp_options', $rmp_options_update );
        //successfully updated
        echo esc_html__( 'Settings Saved', 'rate-my-post' );

      } else { //we are reseting options
        delete_option( 'rmp_options' );
        $rmp_options = rmp_default_options();
        add_option( 'rmp_options', $rmp_options );
        echo esc_html__( 'Settings Reset Done', 'rate-my-post' );
      }
      //user does not have permission or not oding ajax
    } else {
      echo esc_html__( 'You do not have permission to update settings for this plugin!', 'rate-my-post' );
    }
  die();
}

add_action( 'wp_ajax_rmp_options', 'rmp_options_update' );

//8.2. CUSTOMIZE

//add customization options
$rmp_customize_strings = rmp_default_customization();
add_option( 'rmp_customize_strings', $rmp_customize_strings );

//modify customization uptions array on update
rmp_customization_options_modify();

//update or reset customization options
function rmp_customize_update() {
  //only admin can update customization options
    if ( wp_doing_ajax() && current_user_can( 'manage_options' ) ) {
        if ( intval( $_POST['save'] ) === 1 ) { //we are saving customization options not reseting them
          $rmp_customize_update = array();

          $rmp_customize_update['rateTitle'] = sanitize_text_field( $_POST['rateTitle'] );
          $rmp_customize_update['rateSubtitle'] = sanitize_text_field( $_POST['rateSubtitle'] );
          $rmp_customize_update['rateResult'] = sanitize_text_field( $_POST['rateResultText'] );
          $rmp_customize_update['rateResult2'] = sanitize_text_field( $_POST['rateResultText2'] );
          $rmp_customize_update['cookieNotice'] = sanitize_text_field( $_POST['rateCookie'] );
          $rmp_customize_update['noRating'] = sanitize_text_field( $_POST['rateNoVotes'] );
          $rmp_customize_update['afterVote'] = sanitize_text_field( $_POST['rateAfterVote'] );
          $rmp_customize_update['star1'] = sanitize_text_field( $_POST['rateOneStar'] );
          $rmp_customize_update['star2'] = sanitize_text_field( $_POST['rateTwoStar'] );
          $rmp_customize_update['star3'] = sanitize_text_field( $_POST['rateThreeStar'] );
          $rmp_customize_update['star4'] = sanitize_text_field( $_POST['rateFourStar'] );
          $rmp_customize_update['star5'] = sanitize_text_field( $_POST['rateFiveStar'] );
          $rmp_customize_update['socialTitle'] = sanitize_text_field( $_POST['socialTitle'] );
          $rmp_customize_update['socialSubtitle'] = sanitize_text_field( $_POST['socialSubtitle'] );
          $rmp_customize_update['feedbackTitle'] = sanitize_text_field( $_POST['feedbackTitle'] );
          $rmp_customize_update['feedbackSubtitle'] = sanitize_text_field( $_POST['feedbackSubtitle'] );
          $rmp_customize_update['feedbackText'] = sanitize_text_field( $_POST['feedbackText'] );
          $rmp_customize_update['feedbackNotice'] = sanitize_text_field( $_POST['feedbackAfter'] );
          $rmp_customize_update['feedbackButton'] = sanitize_text_field( $_POST['feedbackButton'] );
          $rmp_customize_update['titleFontSize'] = intval( $_POST['titleFontSize'] );
          $rmp_customize_update['subtitleFontSize'] = intval( $_POST['subtitleFontSize'] );
          $rmp_customize_update['textFontSize'] = intval( $_POST['textFontSize'] );
          $rmp_customize_update['titleMarginBottom'] = intval( $_POST['titleMarginBottom'] );
          $rmp_customize_update['subtitleMarginBottom'] = intval( $_POST['subtitleMarginBottom'] );
          $rmp_customize_update['socialFontSize'] = intval( $_POST['socialFontSize'] );
          $rmp_customize_update['feedbackAlert'] = sanitize_text_field( $_POST['feedbackEmpty'] );

          update_option( 'rmp_customize_strings', $rmp_customize_update );
          echo esc_html__( 'Settings Saved', 'rate-my-post' );
      } else { //we are reseting customization options
          delete_option('rmp_customize_strings');
          $rmp_customize_strings = rmp_default_customization();
          add_option( 'rmp_customize_strings', $rmp_customize_strings );
        echo esc_html__( 'Customization Options Reset Done', 'rate-my-post' );
      }
    } else { //does not have permission or not doing ajax
      echo esc_html__( 'You do not have permission to update settings for this plugin!', 'rate-my-post' );
    }
    die();
}
add_action( 'wp_ajax_rmp_customize', 'rmp_customize_update' );

//8.3. ADMIN MENU SECTION

function rmp_options_page() {
    add_menu_page( 'Rate my Post', 'Rate my Post', 'edit_posts', 'rate-my-post', 'rmp_options_display', 'dashicons-thumbs-up', 24 );
}

add_action( 'admin_menu', 'rmp_options_page' );

//callback function - display rmp setings page

function rmp_options_display(){
  echo rmp_options_html();
}

//======================================================================
// 9. HELPER FUNCTIONS
//======================================================================

//9.1. DEFAULT BASIC OPTIONS

function rmp_default_options() {
  $rmp_options = array(
    'posts'           => 1,
    'pages'           => 1,
    'rate_email'      => 1,
    'feedback_email'  => 1,
    'feedback'        => 1,
    'social'          => 1,
    'fb'              => '',
    'pinterest'       => '',
    'flickr'          => '',
    'youtube'         => '',
    'instagram'       => '',
    'twitter'         => '',
    'linkedin'        => '',
    'exclude'         => array(),
    'cookieDisable'   => 1
  );
  return $rmp_options;
}

//9.2. DEFAULT CUSTOMIZATION OPTIONS

function rmp_default_customization() {
  $rmp_customize_strings = array(
    'rateTitle'             => 'How useful was this post?',
    'rateSubtitle'          => 'Click on a star to rate it!',
    'rateResult'            => 'Average rating',
    'rateResult2'           => 'Vote count:',
    'cookieNotice'          => 'You already voted! This vote will not be counted!',
    'noRating'              => 'No votes so far! Be the first to rate this post.',
    'afterVote'             => 'Thank you for rating this post!',
    'star1'                 => 'Not at all useful',
    'star2'                 => 'Somewhat useful',
    'star3'                 => 'Useful',
    'star4'                 => 'Fairly useful',
    'star5'                 => 'Very useful',
    'socialTitle'           => 'As you found this post useful...',
    'socialSubtitle'        => 'Follow us on social media!',
    'feedbackTitle'         => 'We are sorry that this post was not useful for you!',
    'feedbackSubtitle'      => 'Let us improve this post!',
    'feedbackText'          => 'Tell us how we can improve this post?',
    'feedbackNotice'        => 'Thanks for your feedback!',
    'feedbackButton'        => 'Submit Feedback',
    'titleFontSize'         => '',
    'subtitleFontSize'      => '',
    'textFontSize'          => '',
    'titleMarginBottom'     => '',
    'subtitleMarginBottom'  => '',
    'socialFontSize'        => '',
    'feedbackAlert'         => 'Please insert your feedback in the box above!',
  );
  return $rmp_customize_strings;
}

//9.3. FRONTEND HTML
function rmp_print_frontend_html() {

  //get options
  $rmp_options = get_option( 'rmp_options' );
  $rmp_frontend_html =
  '
  <div class="rmp-main">

    <!-- Star rating container -->
    <div class="rmp-rate-view">
      <h2 class="rmp-main-title" style="' . rmp_custom_font( 'titleFontSize' ) . rmp_custom_margin( 'titleMarginBottom' ) . '">' . ( esc_html__( rmp_custom_string( 'rateTitle' ) ) ) . '</h2>
      <p class="rmp-main-subtitle" style="' . rmp_custom_font( 'subtitleFontSize' ) . rmp_custom_margin( 'subtitleMarginBottom' ) . '">' . ( esc_html__( rmp_custom_string( 'rateSubtitle' ) ) ) . '</p>
      <div class="rating-stars">
        <ul id="rmp-stars">
          <li class="star" data-toggle="tooltip" data-placement="top" title="' . (  esc_html__(rmp_custom_string( 'star1' ) ) ) . '" data-value="1">
            <i class="fa fa-star fa-fw"></i>
          </li>
          <li class="star" data-toggle="tooltip" data-placement="top" title="' . (  esc_html__(rmp_custom_string( 'star2' ) ) ) . '" data-value="2">
            <i class="fa fa-star fa-fw"></i>
          </li>
          <li class="star" data-toggle="tooltip" data-placement="top" title="' . (  esc_html__(rmp_custom_string( 'star3' ) ) ) . '" data-value="3">
            <i class="fa fa-star fa-fw"></i>
          </li>
          <li class="star" data-toggle="tooltip" data-placement="top" title="' . (  esc_html__(rmp_custom_string( 'star4' ) ) ) . '" data-value="4">
            <i class="fa fa-star fa-fw"></i>
          </li>
          <li class="star" data-toggle="tooltip" data-placement="top" title="' . (  esc_html__(rmp_custom_string( 'star5' ) ) ) . '" data-value="5">
            <i class="fa fa-star fa-fw"></i>
          </li>
        </ul>
      </div>
      <p id="voting-results" style="' . rmp_custom_font( 'textFontSize' ) . '">' . (  esc_html__(rmp_custom_string( 'rateResult' ) ) ) . ' <span id="rating"></span> / 5. ' . (  esc_html__(rmp_custom_string( 'rateResult2' ) ) ) . ' <span id="votes"></span></p>
      <p id="vote-alert" style="' . rmp_custom_font( 'textFontSize' ) . '"></p>
    </div>

    <!-- Social follow container -->
    <div class="rmp-social-view">
      <h2 class="rmp-main-title" style="' . rmp_custom_font( 'titleFontSize' ) . rmp_custom_margin( 'titleMarginBottom' ) . '">' . ( esc_html__( rmp_custom_string( 'socialTitle' ) ) ) . '</h2>
      <p class="rmp-main-subtitle" style="' . rmp_custom_font( 'subtitleFontSize' ) . rmp_custom_margin( 'subtitleMarginBottom' ) . '">' . ( esc_html__( rmp_custom_string( 'socialSubtitle' ) ) ) . '</p>
      <div class="social-icons">';
      //check if social media links are present
      if( $rmp_options['fb'] !== '' ) {
        $rmp_frontend_html .= '<a target="_blank" href="' . esc_url($rmp_options['fb']) . '" class="fa fa-facebook rmp-social-icon"'. rmp_custom_social_icon() .'></a>';
      };
      if( $rmp_options['pinterest'] !== '' ) {
        $rmp_frontend_html .= '<a target="_blank" href="' . esc_url($rmp_options['pinterest']) . '" class="fa fa-pinterest rmp-social-icon"'. rmp_custom_social_icon() .'></a>';
      };
      if( $rmp_options['youtube'] !== '' ) {
        $rmp_frontend_html .= '<a target="_blank" href="' . esc_url($rmp_options['youtube']) . '" class="fa fa-youtube rmp-social-icon"'. rmp_custom_social_icon() .'></a>';
      };
      if( $rmp_options['flickr'] !== '' ) {
        $rmp_frontend_html .= '<a target="_blank" href="' . esc_url($rmp_options['flickr']) . '" class="fa fa-flickr rmp-social-icon"'. rmp_custom_social_icon() .'></a>';
      };
      if( $rmp_options['instagram'] !== '' ) {
        $rmp_frontend_html .= '<a target="_blank" href="' . esc_url($rmp_options['instagram']) . '" class="fa fa-instagram rmp-social-icon"'. rmp_custom_social_icon() .'></a>';
      };
      if( $rmp_options['twitter'] !== '' ) {
        $rmp_frontend_html .= '<a target="_blank" href="' . esc_url($rmp_options['twitter']) . '" class="fa fa-twitter rmp-social-icon"'. rmp_custom_social_icon() .'></a>';
      };
      if( $rmp_options['linkedin'] !== '' ) {
        $rmp_frontend_html .= '<a target="_blank" href="' . esc_url($rmp_options['linkedin']) . '" class="fa fa-linkedin rmp-social-icon"'. rmp_custom_social_icon() .'></a>';
      };

    $rmp_frontend_html .=
        '
      </div>
    </div>

    <!-- Feedback container -->
    <div class="rmp-feedback-view">
      <h2 class="rmp-main-title" style="' . rmp_custom_font( 'titleFontSize' ) . rmp_custom_margin( 'titleMarginBottom' ) . '">' . ( esc_html__( rmp_custom_string( 'feedbackTitle' ) ) ) . '</h2>
      <p class="rmp-main-subtitle" style="' . rmp_custom_font( 'subtitleFontSize' ) . rmp_custom_margin( 'subtitleMarginBottom' ) . '">' . ( esc_html__( rmp_custom_string( 'feedbackSubtitle' ) ) ) . '</p>
      <div class="form-group feedback-subview">
        <label for="feedback-text" style="' . rmp_custom_font( 'textFontSize' ) . '">' . ( esc_html__( rmp_custom_string( 'feedbackText' ) ) ) . '</label>
        <textarea class="form-control rmp-text-area" rows="5" id="feedback-text"></textarea>
        <div class="rmp-feedback-button-div">
          <button type="button" class="btn btn-primary" id="feedback-button">' . ( esc_html__( rmp_custom_string( 'feedbackButton' ) ) ) . '</button>
        </div>
        <p id="feedback-alert" style="' . rmp_custom_font( 'textFontSize' ) . '"></p>
      </div>
      <div class="feedback-sent">
        <p style="' . rmp_custom_font( 'textFontSize' ) . '">' . ( esc_html__( rmp_custom_string( 'feedbackNotice' ) ) ) . '</p>
      </div>
    </div>

  </div>
  ';
  return $rmp_frontend_html;
}

//9.4. META BOX HTML
function rmp_metabox_html( $votes, $ratingSum, $avgRating, $feedback ) {
  $rmpMetaBox = '
    <div class="rmp-rate-box">
      <div class="form-group rmp-rate-line">
        <label for="votes">' . ( esc_html__( 'Number of Votes', 'rate-my-post' ) ) . ':</label>
        <input type="text" class="form-control" id="votes" value="' . $votes . '">
      </div>
      <hr />
      <div class="form-group rmp-rate-line">
        <label for="sum">' . ( esc_html__( 'Sum of Ratings', 'rate-my-post' ) ) . '</label>
        <input type="text" class="form-control" id="sum" value="' . $ratingSum . '">
      </div>
      <hr />
      <div class="form-group rmp-rate-line">
        <label for="avg">' . ( esc_html__( 'Average Rating', 'rate-my-post' ) ) . ':</label>
        <input type="text" class="form-control" id="avg" disabled value="' . $avgRating . '">
      </div>
      <button type="button" class="btn btn-primary" id="update-rating">' . ( esc_html__( 'Update Rating', 'rate-my-post' ) ) . '</button>
      <p id="update-result"></p>
      <p><i>' . ( esc_html__( 'Tip: Average rating value should be between 1 and 5. To reset the rating insert 0 in both fields and click Update Rating!', 'rate-my-post' ) ) . '</i></p>
      <hr />
    <div class="form-group rmp-rate-line">
      <p class="rmp-rate-bold">' . ( esc_html__( 'Feedback', 'rate-my-post' ) ) . ':</p>
      '. $feedback . '
      </div>
    </div>
  ';
  return $rmpMetaBox;
}

//9.5. OPTIONS HTML

function rmp_options_html() {
    return optionsNavigation() . aboutPlugin() . settingsTab() . customizeTab() . statsTab();
}

//9.6 OPTIONS - NAVIGATION

function optionsNavigation() {
    $rmpNavigation = '
        <h1>Rate my Post</h1>
        <div class="rmp-tab">
          <button class="rmp-tablinks rmp-tabcontent-current" data-tab="rmp-tab-1">' . ( esc_html__( 'Settings', 'rate-my-post' ) ) . '</button>
          <button class="rmp-tablinks" data-tab="rmp-tab-2">' . ( esc_html__( 'Customize', 'rate-my-post' ) ) . '</button>
          <button class="rmp-tablinks" data-tab="rmp-tab-3">' . ( esc_html__( 'Stats', 'rate-my-post' ) ) . '</button>
        </div>
        ';

        return $rmpNavigation;
}

//9.7 ABOUT BOX

function aboutPlugin() {
  $aboutPlugin = '
    <p>
      <span id="rmp-about-show"><a>' . ( esc_html__( 'About Plugin', 'rate-my-post' ) ) . ' &#187;</a></span>
    </p>
    <div id="rmp-about">
      <p>
      ' . ( esc_html__( 'Hi there', 'rate-my-post' ) ) . ',
      </p>
      <p>
      ' . ( esc_html__( 'Thank you for installing Rate my Post plugin. If you like the plugin please rate it', 'rate-my-post' ) ) . ' <a href="https://wordpress.org/support/plugin/rate-my-post/reviews/" target="_blank">' . ( esc_html__( 'here', 'rate-my-post' ) ) . '</a> - ' . ( esc_html__( 'it will take you 5 minutes (less if you are already registered on WordPress) and it means a lot to me since I made this plugin completely for free. If you encounter any problems with the plugin or you miss some features, let me know in the', 'rate-my-post' ) ) . ' <a href="https://wordpress.org/support/plugin/rate-my-post" target="_blank">support forum</a>.
      <br />
      ' . ( esc_html__( 'I hope you will enjoy the plugin', 'rate-my-post' ) ) . '.
      </p>
      <p>
      ' . ( esc_html__( 'Best regards', 'rate-my-post' ) ) . ',
      <br />
      Blaz, the developer of Rate my Post plugin
      </p>
    </div>
  ';

  return $aboutPlugin;
}

//9.8 OPTIONS - SETTINGS TAB

function settingsTab() {
  $rmp_options = get_option( 'rmp_options' );
  //var_dump(get_option( 'rmp_customize_strings' ));
  //settings tab
  $rmpSettingsPage = '
        <div class="rmp-options rmp-tabcontent rmp-tabcontent-current" id="rmp-tab-1">
          <h2>' . ( esc_html__( 'Plugin Settings', 'rate-my-post' ) ) . '</h2>
          <div class="rmp-options-first">
            <div class="rmp-option-group">
              <label class="switch">
                <input id="rmp-posts" type="checkbox" ' . (($rmp_options['posts'] === 2) ? 'checked':"") . '>
                <span class="slider round"></span>
              </label>
              <p class="rmp-option">' . ( esc_html__( 'Include ratings in every post - alternatively you can use shortcode: [ratemypost]', 'rate-my-post' ) ) . '</p>
            </div>
            <div class="rmp-option-group">
              <label class="switch">
                <input id="rmp-pages" type="checkbox" ' . (($rmp_options['pages'] === 2) ? 'checked':"") . '>
                <span class="slider round"></span>
              </label>
                <p class="rmp-option">' . ( esc_html__( 'Include ratings in every page - alternatively you can use shortcode: [ratemypost]', 'rate-my-post' ) ) . '</p>
            </div>
            <div class="form-group">
              <label for="rmp-exclude">' . ( esc_html__( 'Exclude ratings from', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-social-input" id="rmp-exclude" value="' . esc_html( implode(',', $rmp_options['exclude'] ) ) . '">
              <p class="rmp-notice">*' . ( esc_html__( 'Insert comma separated post/page IDs', 'rate-my-post' ) ) . '. <span id="show-rmp-notice"><a>' . ( esc_html__( 'Read more', 'rate-my-post' ) ) . '&raquo;</a></span></p>
              <p id="rmp-notice-hidden">' . ( esc_html__( 'Visit posts/pages menu in your admin dashboard and click on the page/post that you need an ID for. Then check the URL and you should see something like "www.expample.com/wp-admin/post.php?post=61&action=edit". The ID is the number in the URL. In this case it is 61.', 'rate-my-post' ) ) . '</p>
            </div>
            <hr class="rmp-divider" />
            <div class="rmp-option-group">
              <label class="switch">
                <input id="rmp-rate-email" type="checkbox" ' . (($rmp_options['rate_email'] === 2) ? 'checked':"") . '>
                <span class="slider round"></span>
              </label>
              <p class="rmp-option">' . ( esc_html__( 'Send me email for every vote', 'rate-my-post' ) ) . '</p>
            </div>
            <div class="rmp-option-group">
              <label class="switch">
                <input id="rmp-feedback-email" type="checkbox" ' . (($rmp_options['feedback_email'] === 2) ? 'checked':"") . '>
                <span class="slider round"></span>
              </label>
              <p class="rmp-option">' . ( esc_html__( 'Send me email for every feedback - you need to enable show "feedback form" below', 'rate-my-post' ) ) . '</p>
            </div>
            <div class="rmp-option-group">
              <label class="switch">
                <input id="rmp-feedback" type="checkbox" ' . (($rmp_options['feedback'] === 2) ? 'checked':"") . '>
                <span class="slider round"></span>
              </label>
              <p class="rmp-option">' . ( esc_html__( 'If voted 2 stars or less, show "feedback form"', 'rate-my-post' ) ) . '</p>
            </div>
            <div class="rmp-option-group">
              <label class="switch">
                <input id="rmp-social" type="checkbox" ' . (($rmp_options['social'] === 2) ? 'checked':"") . '>
                <span class="slider round"></span>
              </label>
              <p class="rmp-option">' . ( esc_html__( 'If voted 3 stars or more, show "links to social media profiles" - insert links below', 'rate-my-post' ) ) . '</p>
            </div>
            <div class="rmp-option-group">
              <label class="switch">
                <input id="rmp-cookie-disable" type="checkbox" ' . (($rmp_options['cookieDisable'] === 2) ? 'checked':"") . '>
                <span class="slider round"></span>
              </label>
              <p class="rmp-option">' . ( esc_html__( 'Delete cookie on page load - use only for customizing the plugin!', 'rate-my-post' ) ) . '</p>
            </div>
          </div>
          <hr class="rmp-divider" />

          <div class="rmp-options-second">
            <p><i>*' . ( esc_html__( 'If you do not want an icon to be displayed, leave the field below empty!', 'rate-my-post' ) ) . '</i></p>
            <div class="form-group rmp-rate-line">
              <label for="rmp-facebook">' . ( esc_html__( 'Your Facebook Page URL', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-social-input" id="rmp-facebook" value="' . esc_html($rmp_options['fb']) . '">
            </div>
            <div class="form-group rmp-rate-line">
              <label for="rmp-pinterest">' . ( esc_html__( 'Your Pinterest Page URL', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-social-input" id="rmp-pinterest" value="' . esc_html($rmp_options['pinterest']) . '">
            </div>
            <div class="form-group rmp-rate-line">
              <label for="rmp-youtube">' . ( esc_html__( 'Your Youtube Page URL', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-social-input" id="rmp-youtube" value="' . esc_html($rmp_options['youtube']) . '">
            </div>
            <div class="form-group rmp-rate-line">
              <label for="rmp-flickr">' . ( esc_html__( 'Your Flickr Page URL', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-social-input" id="rmp-flickr" value="' . esc_html($rmp_options['flickr']) . '">
            </div>
            <div class="form-group rmp-rate-line">
              <label for="rmp-instagram">' . ( esc_html__( 'Your Instagram Page URL', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-social-input" id="rmp-instagram" value="' . esc_html($rmp_options['instagram']) . '">
            </div>
            <div class="form-group rmp-rate-line">
              <label for="rmp-twitter">' . ( esc_html__( 'Your Twitter Page URL', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-social-input" id="rmp-twitter" value="' . esc_html($rmp_options['twitter']) . '">
            </div>
            <div class="form-group rmp-rate-line">
              <label for="rmp-linkedin">' . ( esc_html__( 'Your Linkedin Page URL', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-social-input" id="rmp-linkedin" value="' . esc_html($rmp_options['linkedin']) . '">
            </div>
          </div>
          <button type="button" class="btn btn-primary" id="rmp-save-settings">' . ( esc_html__( 'Save Settings', 'rate-my-post' ) ) . '</button>
          <button type="button" class="btn btn-primary" id="rmp-reset-settings">' . ( esc_html__( 'Reset Settings', 'rate-my-post' ) ) . '</button>
          <p id="rmp-options-update-alert"></p>
        </div>
    ';
    return $rmpSettingsPage;
}

//9.9 OPTIONS - CUSTOMIZE TAB

function customizeTab() {
  $rmpCustomizePage = '
    <div class="rmp-stats rmp-tabcontent" id="rmp-tab-2">
      <h2>' . ( esc_html__( 'Customize Plugin', 'rate-my-post' ) ) . '</h2>
      <p><i>*' . ( esc_html__( 'Tip: First enable delete cookie on page load in settings. Add shortcode [ratemypost] to one of your posts and open it in the preview mode. Then custmize this plugin to your liking - after saving settings reload the post in the preview mode to see the changes you have made. After testing reset the rating - see the stats section.', 'rate-my-post' ) ) . '</i></p>
      <h3>' . ( esc_html__( 'Strings - Rating View', 'rate-my-post' ) ) . '</h3>
      <div class="admin-main-view">
        <table id="rmp-customize-main-table">
          <tr>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-rate-title">' . ( esc_html__( 'Title', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-rate-title" value="' . esc_html( rmp_custom_string( 'rateTitle' ) ) . '">
            </div></td>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-rate-subtitle">' . ( esc_html__( 'Subtitle', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-rate-subtitle" value="' . esc_html( rmp_custom_string( 'rateSubtitle' ) ) . '">
            </div></td>
          </tr>
          <tr>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-rate-result">' . ( esc_html__( 'Result text - average rating', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-rate-result" value="' . esc_html( rmp_custom_string( 'rateResult' ) ) . '">
            </div></td>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-rate-result2">' . ( esc_html__( 'Result text - vote count', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-rate-result2" value="' . esc_html( rmp_custom_string( 'rateResult2' ) ) . '">
            </div></td>
          </tr>
          <tr>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-rate-cookie">' . ( esc_html__( 'Text if somebody tries to vote twice', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-rate-cookie" value="' . esc_html( rmp_custom_string( 'cookieNotice' ) ) . '">
            </div></td>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-rate-norate">' . ( esc_html__( 'Result text if no votes', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-rate-norate" value="' . esc_html( rmp_custom_string( 'noRating' ) ) . '">
            </div></td>
          </tr>
          <tr>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-rate-aftervote">' . ( esc_html__( 'Text after vote', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-rate-aftervote" value="' . esc_html( rmp_custom_string( 'afterVote' ) ) . '">
            </div></td>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-rate-star1">' . ( esc_html__( 'One star hover text', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-rate-star1" value="' . esc_html( rmp_custom_string( 'star1' ) ) . '">
            </div></td>
          </tr>
          <tr>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-rate-star2">' . ( esc_html__( 'Two stars hover text', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-rate-star2" value="' . esc_html( rmp_custom_string( 'star2' ) ) . '">
            </div></td>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-rate-star3">' . ( esc_html__( 'Three stars hover text', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-rate-star3" value="' . esc_html( rmp_custom_string( 'star3' ) ) . '">
            </div></td>
          </tr>
          <tr>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-rate-star4">' . ( esc_html__( 'Four stars hover text', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-rate-star4" value="' . esc_html( rmp_custom_string( 'star4' ) ) . '">
            </div></td>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-rate-star5">' . ( esc_html__( 'Five stars hover text', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-rate-star5" value="' . esc_html( rmp_custom_string( 'star5' ) ) . '">
            </div></td>
          </tr>
        </table>
      </div>
      <hr class="rmp-divider" />
      <div class="admin-social-view">
        <h3>' . ( esc_html__( 'Strings - Social View', 'rate-my-post' ) ) . '</h3>
        <table id="rmp-customize-social-table">
          <tr>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-social-title">' . ( esc_html__( 'Title', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-social-title" value="' . esc_html( rmp_custom_string( 'socialTitle' ) ) . '">
            </div></td>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-social-subtitle">' . ( esc_html__( 'Subtitle', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-social-subtitle" value="' . esc_html( rmp_custom_string( 'socialSubtitle' ) ) . '">
            </div></td>
          </tr>
        </table>
      </div>
      <hr class="rmp-divider" />
      <div class="admin-feedback-view">
        <h3>' . ( esc_html__( 'Strings - Feedback View', 'rate-my-post' ) ) . '</h3>
        <table id="rmp-customize-feedback-table">
          <tr>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-feedback-title">' . ( esc_html__( 'Title', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-feedback-title" value="' . esc_html( rmp_custom_string( 'feedbackTitle' ) ) . '">
            </div></td>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-feedback-subtitle">' . ( esc_html__( 'Subtitle', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-feedback-subtitle" value="' . esc_html( rmp_custom_string( 'feedbackSubtitle' ) ) . '">
            </div></td>
          </tr>
          <tr>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-feedback-text">' . ( esc_html__( 'Text', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-feedback-text" value="' . esc_html( rmp_custom_string( 'feedbackText' ) ) . '">
            </div></td>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-feedback-notice">' . ( esc_html__( 'Text after sending feedback', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-feedback-notice" value="' . esc_html( rmp_custom_string( 'feedbackNotice' ) ) . '">
            </div></td>
          </tr>
          <tr>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-feedback-button">' . ( esc_html__( 'Feedback button text', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-feedback-button" value="' . esc_html( rmp_custom_string( 'feedbackButton' ) ) . '">
            </div></td>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-feedback-empty">' . ( esc_html__( 'Text if feedback is empty', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-input" id="rmp-feedback-empty" value="' . esc_html( rmp_custom_string( 'feedbackAlert' ) ) . '">
            </div></td>
          </tr>
        </table>
      </div>
      <hr class="rmp-divider" />
      <div class="admin-custom-style">
        <h3>' . ( esc_html__( 'Style', 'rate-my-post' ) ) . '</h3>
        <p><i>*' . ( esc_html__( 'Leave empty or insert 0 for default style.', 'rate-my-post' ) ) . '</i></p>
        <table id="rmp-customize-style-table">
          <tr>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-title-font">' . ( esc_html__( 'Title Font Size', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-style-input" id="rmp-title-font" value="' . esc_html( rmp_custom_style( 'titleFontSize' ) ) . '">px
            </div></td>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-subtitle-font">' . ( esc_html__( 'Subtitle Font Size', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-style-input" id="rmp-subtitle-font" value="' . esc_html( rmp_custom_style( 'subtitleFontSize' ) ) . '">px
            </div></td>
          </tr>
          <tr>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-text-font">' . ( esc_html__( 'Text Font Size', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-style-input" id="rmp-text-font" value="' . esc_html( rmp_custom_style( 'textFontSize' ) ) . '">px
            </div></td>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-social-font">' . ( esc_html__( 'Social Icon Size', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-style-input" id="rmp-social-font" value="' . esc_html( rmp_custom_style( 'socialFontSize' ) ) . '">px
            </div></td>
            </tr>
            <tr>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-title-margin">' . ( esc_html__( 'Title Bottom Margin', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-style-input" id="rmp-title-margin" value="' . esc_html( rmp_custom_style( 'titleMarginBottom' ) ) . '">px
            </div></td>
            <td><div class="form-group rmp-rate-line">
              <label for="rmp-subtitle-margin">' . ( esc_html__( 'Subtitle Bottom Margin', 'rate-my-post' ) ) . ':</label>
              <input type="text" class="form-control rmp-customize-style-input" id="rmp-subtitle-margin" value="' . esc_html(rmp_custom_style( 'subtitleMarginBottom' ) ) . '">px
            </div></td>
          </tr>
      </table>
      </div>
      <button type="button" class="btn btn-primary" id="rmp-save-customization">' . ( esc_html__( 'Save Customization Options', 'rate-my-post' ) ) . '</button>
      <button type="button" class="btn btn-primary" id="rmp-reset-customization">' . ( esc_html__( 'Reset Customization Options', 'rate-my-post' ) ) . '</button>
      <p id="rmp-customization-update-alert"></p>
    </div>
  ';
  return $rmpCustomizePage;
}

//9.10 OPTIONS - STATS TAB

function statsTab() {

  //stats tab
  $rmpPostsArray = array();
  //args for the loop
  $args = array(
     'post_type'       => array( 'post','page' ),
     'posts_per_page'  => -1
  );
  $the_query = new WP_Query( $args );
  // The Loop
  if ( $the_query->have_posts() ) {
    while ( $the_query->have_posts() ) {
      $the_query->the_post();
      //data we'll need
      $postID = get_the_ID();
      $title = get_the_title();
      $editLink = get_edit_post_link( $postID );
      $votes = intval( get_post_meta( get_the_ID(), 'rmp_vote_count', true ) );
      $sum = intval( get_post_meta( get_the_ID(), 'rmp_rating_val_sum', true ) );
      $feedback = get_post_meta( get_the_ID(), 'rmp_feedback_val', true );
      //push to array
      $rmpPostsArray[$postID]['title'] = $title;
      $rmpPostsArray[$postID]['edit'] = $editLink;
      $rmpPostsArray[$postID]['votes'] = $votes;
      $rmpPostsArray[$postID]['sum'] = $sum;
      //calculate feedback count
      if( $feedback !== '' ) {
        $feedbackArray = explode( '<br />', $feedback );
        $feedbackNumber = count( $feedbackArray ) - 1;
      } else {
        $feedbackNumber = 0;
      }
      $rmpPostsArray[$postID]['feedback'] = $feedbackNumber;
      //calculate the average rating
      if( $sum !== 0 && $votes !== 0 ) {
        $avgRating = round( ($sum / $votes), 1 );
      } else {
        $avgRating = 0;
      }
      $rmpPostsArray[$postID]['avg'] = $avgRating;
    }
    // Restore original Post Data
    wp_reset_postdata();
  } else {
    // no posts found
  }
  //generate dynamic data for table
  $tableRows = '';
  foreach( $rmpPostsArray as $rmpPost ) {
    if( $rmpPost["votes"] !== 0 ) {
      $tableRows .=
      '<tr>
        <td><a href="' . $rmpPost["edit"] . '" target="_blank">' . $rmpPost["title"] . '</a></td>
        <td>' . $rmpPost["votes"] . '</td>
        <td>' . $rmpPost["avg"] . '</td>
        <td>' . $rmpPost["feedback"] . '</td>
      </tr>';
    }
  }
  //create the table
  $statsPage = '
  <div class="rmp-stats rmp-tabcontent" id="rmp-tab-3">
    <h2>' . ( esc_html__( 'Rate my Post Stats', 'rate-my-post' ) ) . '</h2>
    <p><i>*' . ( esc_html__( 'Displaying only rated posts and pages! To see feedback or change ratings click on a post/page title below and find the Rate my Post meta box at the bottom.', 'rate-my-post' ) ) . '</i></p>
    <table id="rmp-table">
      <tr>
        <th>' . ( esc_html__( 'Title', 'rate-my-post' ) ) . '</th>
        <th>' . ( esc_html__( 'Votes', 'rate-my-post' ) ) . '</th>
        <th>' . ( esc_html__( 'Average Rating', 'rate-my-post' ) ) . '</th>
        <th>' . ( esc_html__( 'Feedback', 'rate-my-post' ) ) . '</th>
      </tr>' . $tableRows . '
    </table>
  </div>
  ';
  return $statsPage;
}

//9.11. CUSTOM STRINGS - FRONT AND BACKEND

function rmp_custom_string( $type ) {
  $rmpCustomStrings = get_option( 'rmp_customize_strings' );
  $rmCustomString = $rmpCustomStrings[$type];
  return sanitize_text_field( $rmCustomString );
}

//9.12 CUSTOM STYLE - BACKEND

function rmp_custom_style( $type ) {
  $rmpCustomStringsStyles = get_option( 'rmp_customize_strings' );
  $rmpCustomStyle = intval( $rmpCustomStringsStyles[$type] );
  if ( $rmpCustomStyle !== 0 ) {
    return $rmpCustomStyle;
  } else {
    return '';
  }
}

//9.13 CUSTOM STYLE - FONT SIZE FRONTEND

function rmp_custom_font( $type ) {
  $rmpCustomFont = get_option( 'rmp_customize_strings' );
  $rmpCustomFont = intval( $rmpCustomFont[$type] );
  if ( $rmpCustomFont !== 0 ) {
    return 'font-size:' . $rmpCustomFont . 'px;';
  } else {
    return '';
  }
}

//9.14 CUSTOM STYLE - MARGIN FRONTEND

function rmp_custom_margin( $type ) {
  $rmpCustomMargin = get_option( 'rmp_customize_strings' );
  $rmpCustomMargin = intval( $rmpCustomMargin[$type] );
  if ( $rmpCustomMargin !== 0 ) {
    return 'margin-bottom:' . $rmpCustomMargin . 'px;';
  } else {
    return '';
  }
}

//9.15 CUSTOM STYLE - SOCIAL ICON FRONTEND

function rmp_custom_social_icon() {
  $rmpCustomSocial = get_option( 'rmp_customize_strings' );
  $rmpCustomSocial = intval( $rmpCustomSocial['socialFontSize'] );
  if ( $rmpCustomSocial !== 0 ) {
    $fontSize = $rmpCustomSocial;
    $padding = intval ($fontSize * 0.67 );
    $width = intval( $fontSize * 2.33 );;
    return 'style="font-size:' . $fontSize . 'px;padding:' . $padding . 'px;width:' . $width . 'px"';
  } else {
    return '';
  }
}

//9.16 VERSION CHANGE OPTIONS UPDATE

function rmp_options_modify() {
  $rmp_options = get_option( 'rmp_options' );
  if ( count( $rmp_options ) === 10 ) { //update from version 1.0 to 1.1.0
    $rmp_options['instagram'] = '';
    $rmp_options['twitter'] = '';
    $rmp_options['linkedin'] = '';
    $rmp_options['exclude'] = array();
    $rmp_options['cookieDisable'] = 1;

    update_option( 'rmp_options', $rmp_options );
  }
}

//9.17 VERSION CHANGE CUSTOMIZATION OPTIONS

function rmp_customization_options_modify() {
  $rmp_customization_options = get_option( 'rmp_customize_strings' );
  if ( count( $rmp_customization_options ) === 25 ) { //update from version 1.1.1 to 1.1.2
    $rmp_customization_options['feedbackAlert'] = 'Please insert your feedback in the box above!';
    update_option( 'rmp_customize_strings', $rmp_customization_options );
  }
}
